#include <algorithm>
#include <array>
#include <iostream>
#include <set>
#include <vector>

void print(const auto& container) {
	if (container.empty()) {
		std::cout << "{}\n";
		return;
	}
	char sep = '{';
	for (auto& elem : container) {
		std::cout << sep << ' ' << elem;
		sep = ',';
	}
	std::cout << " }\n";
}

int main() {
	std::set s = { 1, 21, -7, 4 };

	std::vector<int> vec;
	vec.resize(7);
	print(vec);

	std::copy(s.begin(), s.end(), vec.begin() + 2);
	print(vec);

	std::copy(s.begin(), s.end(),
	          std::back_inserter(vec));
	print(vec);

	std::cout << "---\n";
	s.clear();

	std::copy(vec.begin(), vec.end(),
	          std::inserter(s, s.end()));
	print(s);

	vec = { 1, 2, 3 };
	vec.insert(vec.end(), s.begin(), s.end());
	print(vec);

	std::cout << "---\n";

	std::array arr = { 1, 2, 3, 4, 5 };
	std::copy_if(s.begin(), s.end(), arr.begin(),
	             [](int num) { return num % 2 == 0; });
	print(arr);

	std::cout << "---\n";
	s = { 0, 21, -7, 4 };
	vec.clear();

	std::transform(s.begin(), s.end(), std::back_inserter(vec),
	               [](int num) { return 2 * num + 1; });
	print(vec);

	std::transform(s.begin(), s.end(), vec.begin(), arr.begin(),
	               [](int a, int b) { return a * b; });
	print(arr);

}
