#include <algorithm>
#include <iostream>
#include <vector>

void show_iter(const auto& container, auto iter) {
	for (char c : container) {
		std::cout << c << ' ';
	}
	std::cout << '\n';
	auto dist = iter - container.begin();
	for (int i = 0; i < dist; ++i) {
		std::cout << "  ";
	}
	std::cout << "^\n";
}

int main() {
	std::vector letters = { 'n', 'u', 'q', 'n', 'e', 'H' };

	auto it1 = std::find(letters.begin(),
	                     letters.end(), 'q');
	show_iter(letters, it1);
	std::cout << "------------\n";

	auto it2 = std::find_if(
		letters.begin(), letters.end(),
		[](unsigned char c) {
			return std::isupper(c);
		});
	show_iter(letters, it2);
	std::cout << "------------\n";

	// note: std::isupper is not addressable, so we need to use lambda;
	// for an explanation of why we use unsigned char here, read the notes
	// section of https://en.cppreference.com/w/cpp/string/byte/isupper
}
