#include <algorithm>
#include <iostream>
#include <set>
#include <vector>

void print(const auto& container) {
	if (container.empty()) {
		std::cout << "{}\n";
		return;
	}
	char sep = '{';
	for (auto& elem : container) {
		std::cout << sep << ' ' << elem;
		sep = ',';
	}
	std::cout << " }\n";
}

int main() {
	std::set s1 = { 9, 8, 0, 1, 5 };
	std::set s2 = { 3, 4, 0, 7, 9 };
	std::vector<int> res;

	std::set_union(s1.begin(), s1.end(),
	               s2.begin(), s2.end(),
	               std::back_inserter(res));
	print(res);
	res.clear();

	std::vector v1 = { 1, 1, 3, 3, 7, 7, 7 };
	std::vector v2 = { 1, 2, 3, 4, 5, 6, 7 };
	res.resize(v1.size() + v2.size());

	auto end = std::set_union(v1.begin(), v1.end(),
	                          v2.begin(), v2.end(),
	                          res.begin());
	print(res);
	res.erase(end, res.end());
	print(res);

	v1 = { -1, -3, -4 };
	v2 = { 1, 2, 3, 5 };
	res.clear();

	std::set_union(
		v1.begin(), v1.end(),
		v2.begin(), v2.end(),
		std::back_inserter(res),
		[](int a, int b) { return std::abs(a) < std::abs(b); }
	);
	print(res);

	res.clear();
	std::merge(
		v1.begin(), v1.end(),
		v2.begin(), v2.end(),
		std::back_inserter(res),
		[](int a, int b) { return std::abs(a) < std::abs(b); }
	);
	print(res);

}
