#include <algorithm>
#include <iostream>
#include <map>
#include <ranges>
#include <vector>

void print(const auto& container) {
	if (container.empty()) {
		std::cout << "{}\n";
		return;
	}
	char sep = '{';
	for (auto& elem : container) {
		std::cout << sep << ' ' << elem;
		sep = ',';
	}
	std::cout << " }\n";
}

int main() {
	namespace views = std::views;
	namespace ranges = std::ranges;

	std::vector<int> vec;
	vec.resize(10);

	ranges::fill(vec | views::take(5), 1);
	print(vec);

	ranges::generate(vec | views::reverse | views::drop(1) | views::take(4),
		[pow = 1]() mutable { return pow *= 2; });
	print(vec);

	auto rvec = views::reverse(vec);
	rvec[0] = 1;
	print(vec);

	auto mvec = vec | views::transform([](int num) { return num * 10; });
	// mvec[0] = 0;  // not modifiable
	std::cout << mvec[5] << '\n';

	std::map<char, int> m = {
		{ 'a', 7 },
		{ 'c', 9 },
		{ 'x', 0 },
		{ 'b', 3 },
		{ 'n', 1 },
	};

	for (int& v : m | views::values) {
		v *= 2;
	}

	for (auto [k, v] : m) {
		std::cout << k << ": " << v << '\n';
	}
}
